@@ -10,26 +10,42 @@ from rich.table import Table
 
 from neuralspace.apis import get_async_http_session
 from neuralspace.constants import (
+    ARROW_UP,
     AUTHORIZATION,
+    BIN,
+    BOLD_END,
+    BOLD_START,
+    BOOK,
     COMMON_HEADERS,
     COMPLETED,
     COUNT,
     CREATE_PROJECT_COMMAND,
+    CROSS,
+    DARK_ORANGE_END,
+    DARK_ORANGE_START,
     DATA,
     DEAD,
     DEPLOY_MODEL_COMMAND,
+    DOWN_ARROW,
     END_INDEX,
     ENTITIES,
     ENTITY_ACC,
+    ERROR,
     EXAMPLE,
     EXAMPLE_ID,
     EXAMPLES,
     FAILED,
+    FAST_FORWARD,
     FILTER,
+    FINGER_RIGHT,
+    GREEN_TICK,
+    HASH,
+    INFO,
     INITIATED,
     INTENT,
     INTENT_ACCURACY,
     INTENT_CLASSIFIER_METRICS,
+    KEY,
     LANGUAGE,
     LANGUAGES,
     LAST_STATUS_UPDATED,
@@ -43,16 +59,31 @@ from neuralspace.constants import (
     NUMBER_OF_EXAMPLES,
     NUMBER_OF_INTENTS,
     NUMBER_OF_MODELS,
+    NUMBERS_IN_SQUARE,
+    OM,
+    ORANGE_END,
+    ORANGE_START,
     PAGE_NUMBER,
     PAGE_SIZE,
     PARSE_MODEL_COMMAND,
+    PEN_AND_PAPER,
+    PERSON_DUMBELL,
+    PERSON_HERE,
+    PERSON_STANDING,
+    PERSON_TAKING,
+    PIN,
     PREPARED,
     PROJECT_ID,
     PROJECT_NAME,
     PROJECTS,
     QUEUED,
+    RED_END,
+    RED_START,
     REPLICAS,
+    SAD_SMILEY,
+    SAND_CLOCK,
     SEARCH,
+    SOUP,
     START_INDEX,
     TEXT,
     TIMED_OUT,
@@ -62,6 +93,7 @@ from neuralspace.constants import (
     TRAINING_TIME,
     TYPE,
     UPLOAD_DATASET_COMMAND,
+    WRITING,
     neuralspace_url,
 )
 from neuralspace.nlu.constants import (
@@ -91,9 +123,7 @@ console = Console()
 
 
 async def get_languages() -> Dict[Text, Any]:
-    console.print(
-        "> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching all supported languages for NLU"
-    )
+    console.print(f"> {INFO} {DOWN_ARROW}️ Fetching all supported languages for NLU")
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
     async with get_async_http_session().get(
@@ -102,24 +132,27 @@ async def get_languages() -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
+            console.print(f"> {INFO} {GREEN_TICK} Successfully Fetched Languages")
+            table = Table()
+            table.add_column("Language")
+            table.add_column("Code")
+            for row in json_response["data"]:
+                table.add_row(row["language"], row["code"])
+            console.print(table)
             console.print(
-                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully created project"
-            )
-            console.print(f"{json.dumps(json_response, indent=4)}")
-            console.print(
-                f"⏩ To create the project: [dark_orange3]{CREATE_PROJECT_COMMAND}[/dark_orange3]"
+                f"{FAST_FORWARD} To create the project: {DARK_ORANGE_START}{CREATE_PROJECT_COMMAND}{DARK_ORANGE_END}"
             )
         else:
-            console.print("> [red]ERROR[/red] ❌ Failed to create project")
+            console.print(f"> {ERROR} {CROSS} Failed to create project")
             console.print(
-                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
             )
     return json_response
 
 
 async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text, Any]:
     console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Creating a project called "
+        f"> {INFO} Creating a project called "
         f"{project_name} in languages: {', '.join(languages)}!"
     )
     payload = {PROJECT_NAME: project_name, LANGUAGE: languages}
@@ -133,17 +166,10 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
+            console.print(f"> {INFO}" f" {KEY} Retrieving credentials from config...")
+            console.print(f"> {INFO} " f"{GREEN_TICK} Successfully created project!")
             console.print(
-                "> [deep_sky_blue2]INFO[/deep_sky_blue2]"
-                " 🗝 Retrieving credentials from config..."
-            )
-            console.print(
-                "> [deep_sky_blue2]INFO[/deep_sky_blue2] "
-                "✅ Successfully created project!"
-            )
-            console.print(
-                "> [deep_sky_blue2]INFO[/deep_sky_blue2] "
-                "💁 Here is your project information..."
+                f"> {INFO} " f"{PERSON_HERE} Here is your project information..."
             )
             table.add_column("Name")
             table.add_column("Language")
@@ -163,21 +189,19 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
             )
             console.print(table)
             console.print(
-                f"⏩ Upload data to your project using this command:"
-                f" [dark_orange3]{UPLOAD_DATASET_COMMAND}[/dark_orange3]"
+                f"{FAST_FORWARD} Upload data to your project using this command:"
+                f" {DARK_ORANGE_START}{UPLOAD_DATASET_COMMAND}{DARK_ORANGE_END}"
             )
         else:
-            console.print("> [red]ERROR[/red] ❌ Failed to create project")
+            console.print(f"> {ERROR} {CROSS} Failed to create project")
             console.print(
-                f'''> Reason for failure 😔:- " [red]{json_response[DATA]['error']}[/red] "'''
+                f'''> Reason for failure {SAD_SMILEY}:- " {RED_START}{json_response[DATA]['error']}{RED_END} "'''
             )
     return json_response
 
 
 async def delete_project(project_id: Text) -> Dict[Text, Any]:
-    console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting project with id: {project_id}"
-    )
+    console.print(f"> {INFO} {BIN} Deleting project with id: {project_id}")
     payload = {PROJECT_ID: project_id}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -188,16 +212,14 @@ async def delete_project(project_id: Text) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
+            console.print(f"> {INFO} {GREEN_TICK} Successfully deleted project")
             console.print(
-                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted project"
-            )
-            console.print(
-                f"⏩ To create the project:  [dark_orange3]{CREATE_PROJECT_COMMAND}[/dark_orange3]"
+                f"{FAST_FORWARD} To create the project:  {DARK_ORANGE_START}{CREATE_PROJECT_COMMAND}{DARK_ORANGE_END}"
             )
         else:
-            console.print("> [red]ERROR[/red] ❌ Failed to delete projects")
+            console.print(f"> {ERROR} {CROSS} Failed to delete projects")
             console.print(
-                f"> Reason for failure 😔:- [red]{json_response['message']}[/red]"
+                f"> Reason for failure {SAD_SMILEY}:- {RED_START}{json_response['message']}{RED_END}"
             )
     return json_response
 
@@ -243,17 +265,17 @@ async def list_projects(
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
             console.print(
-                f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📚 Your projects for Page {page_number} "
+                f"> {INFO} {BOOK} Your projects for Page {page_number} "
                 f"with Page Size: {page_size}"
             )
             print_projects_table(json_response, verbose)
             console.print(
-                f"⏩ To upload your dataset: [dark_orange3]{UPLOAD_DATASET_COMMAND}[/dark_orange3]"
+                f"{FAST_FORWARD} To upload your dataset: {DARK_ORANGE_START}{UPLOAD_DATASET_COMMAND}{DARK_ORANGE_END}"
             )
         else:
-            console.print("> [red]ERROR[/red] ❌ Failed to list projects")
+            console.print(f"> {ERROR} {CROSS} Failed to list projects")
             console.print(
-                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
             )
     return json_response
 
@@ -267,7 +289,7 @@ def print_examples_table(examples: Dict[Text, Any], verbose: bool = False):
         table.add_column("N Entities", style="#c47900")
 
     console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Examples Count: {examples[DATA][COUNT]}"
+        f"> {INFO} {NUMBERS_IN_SQUARE} Total Examples Count: {examples[DATA][COUNT]}"
     )
     for data in examples[DATA][EXAMPLES]:
         args = [data[EXAMPLE_ID], data[TEXT]]
@@ -289,11 +311,11 @@ async def list_examples(
     verbose: bool = False,
 ) -> Dict[Text, Any]:
     console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching Examples with filter: \n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] #️⃣ [bold]Project ID:[/bold] [orange]{project_id}[orange]\n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🕉️ Language: {language}\n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🍲 Prepared: {prepared}\n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📌 type: {type}"
+        f"> {INFO} {DOWN_ARROW}️ Fetching Examples with filter: \n"
+        f"> {INFO} {HASH} {BOLD_START}Project ID:{BOLD_END} {ORANGE_START}{project_id}{ORANGE_END}\n"
+        f"> {INFO} {OM} Language: {language}\n"
+        f"> {INFO} {SOUP} Prepared: {prepared}\n"
+        f"> {INFO} {PIN} type: {type}"
     )
     payload = {
         FILTER: {
@@ -319,17 +341,17 @@ async def list_examples(
         if is_success_status(response.status):
             print_examples_table(json_response, verbose)
             console.print(
-                f"⏩ To train the model: [dark_orange3]{TRAIN_MODEL_COMMAND}[/dark_orange3]"
+                f"{FAST_FORWARD} To train the model: {DARK_ORANGE_START}{TRAIN_MODEL_COMMAND}{DARK_ORANGE_END}"
             )
             console.print(
-                "[red]📝NOTE: To train a model in a project, the project must have minimum"
-                " [orange4]2[/orange4] intent and every intent must atleast have[/red] "
-                "[orange4]10[/orange4] [red]training examples[/red]"
+                f"{RED_START}{PEN_AND_PAPER}NOTE: To train a model in a project, the project must have minimum"
+                f" [orange4]2[/orange4] intent and every intent must atleast have{RED_END} "
+                f"[orange4]10[/orange4] {RED_START}training examples{RED_END}"
             )
         else:
-            console.print("> [red]ERROR[/red] ❌ Failed to list examples")
+            console.print(f"> {ERROR} {CROSS} Failed to list examples")
             console.print(
-                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
             )
 
     return json_response
@@ -366,7 +388,7 @@ def print_models_table(models: Dict[Text, Any], verbose: bool):
         table.add_column("Training Message")
 
     console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Models Count: {models[DATA][COUNT]}"
+        f"> {INFO} {NUMBERS_IN_SQUARE} Total Models Count: {models[DATA][COUNT]}"
     )
     for data in models[DATA][MODELS]:
         args = [data[MODEL_ID], data[MODEL_NAME]]
@@ -401,10 +423,10 @@ async def list_models(
     verbose: bool,
 ) -> Dict[Text, Any]:
     console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching models with filter: \n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 👉️ Project ID: {project_id}\n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗣️ Language: {language}\n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🏋️ Training Statuses: {training_status}"
+        f"> {INFO} {DOWN_ARROW}️ Fetching models with filter: \n"
+        f"> {INFO} {FINGER_RIGHT} Project ID: {project_id}\n"
+        f"> {INFO} {PERSON_TAKING} Language: {language}\n"
+        f"> {INFO} {PERSON_DUMBELL}️ Training Statuses: {training_status}"
     )
     payload = {
         FILTER: {PROJECT_ID: project_id, LANGUAGE: language},
@@ -425,20 +447,18 @@ async def list_models(
         if is_success_status(response.status):
             print_models_table(json_response, verbose)
             console.print(
-                f"⏩ To deploy the model: [orange4]{DEPLOY_MODEL_COMMAND}[/dark_orange3]"
+                f"{FAST_FORWARD} To deploy the model: [orange4]{DEPLOY_MODEL_COMMAND}{DARK_ORANGE_END}"
             )
         else:
-            console.print("> [red]ERROR[/red] ❌ Failed to list models")
+            console.print(f"> {ERROR} {CROSS} Failed to list models")
             console.print(
-                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
             )
     return json_response
 
 
 async def delete_examples(example_ids: List[Text]) -> Dict[Text, Any]:
-    console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting Example with id: {example_ids}"
-    )
+    console.print(f"> {INFO} {BIN} Deleting Example with id: {example_ids}")
     payload = {EXAMPLE_ID: example_ids}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -449,13 +469,11 @@ async def delete_examples(example_ids: List[Text]) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print(
-                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted example!"
-            )
+            console.print(f"> {INFO} {GREEN_TICK} Successfully deleted example!")
         else:
-            console.print("> [red]ERROR[/red] ❌ Failed to delete examples")
+            console.print(f"> {ERROR} {CROSS} Failed to delete examples")
             console.print(
-                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
             )
     return json_response
 
@@ -470,12 +488,10 @@ async def upload_dataset(
     responses = []
     error_examples = []
     console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Uploading {len(nlu_data) - skip_first} "
+        f"> {INFO} Uploading {len(nlu_data) - skip_first} "
         f"examples for project {project_id} and language {language}"
     )
-    console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Skipping first {skip_first} examples"
-    )
+    console.print(f"> {INFO} Skipping first {skip_first} examples")
     for chunk_id, example in track(
         enumerate(nlu_data[skip_first:]),
         description="[bold orange4]uploading[/bold orange4]...",
@@ -496,31 +512,27 @@ async def upload_dataset(
                 responses.append(json_response)
             else:
                 console.print(
-                    f"> [red]ERROR[/red] ❌ Failed to upload example with text "
-                    f"[dark_orange3]{example['text']}[/dark_orange3]"
+                    f"> {ERROR} {CROSS} Failed to upload example with text "
+                    f"{DARK_ORANGE_START}{example['text']}{DARK_ORANGE_END}"
                 )
                 console.print(
                     f"> Failed on example: \n{json.dumps(example, indent=4, ensure_ascii=False)}"
                 )
                 console.print(
-                    f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+                    f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
                 )
                 error_examples.append(example)
                 if ignore_errors:
                     continue
                 else:
                     break
-    console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Uploaded {len(responses)} examples"
-    )
-    console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ❌ Failed on {len(error_examples)} examples"
-    )
+    console.print(f"> {INFO} {GREEN_TICK} Uploaded {len(responses)} examples")
+    console.print(f"> {INFO} {CROSS} Failed on {len(error_examples)} examples")
     console.print(f"To train your model: {TRAIN_MODEL_COMMAND}")
     with open("failed_examples.json", "w") as f:
         json.dump(error_examples, f, ensure_ascii=False)
         console.print(
-            "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✍️ Writing failed examples into failed_examples.json"
+            f"> {INFO} {WRITING} Writing failed examples into failed_examples.json"
         )
     return responses
 
@@ -536,7 +548,7 @@ async def wait_till_training_completes(
         HEADERS = copy(COMMON_HEADERS)
         HEADERS[AUTHORIZATION] = get_auth_token()
         console.print(
-            f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⏳ Waiting for model to "
+            f"> {INFO} {SAND_CLOCK} Waiting for model to "
             f"get trained; model id: {model_id}"
         )
         current_status = ""
@@ -558,23 +570,22 @@ async def wait_till_training_completes(
                         ):
                             if json_response[DATA][TRAINING_STATUS] == COMPLETED:
                                 console.print(
-                                    f"⏩ To deploy your model on Neuralspace platform: "
-                                    f"[orange4]{DEPLOY_MODEL_COMMAND}[/dark_orange3]"
+                                    f"{FAST_FORWARD} To deploy your model on Neuralspace platform: "
+                                    f"{DARK_ORANGE_START}{DEPLOY_MODEL_COMMAND}{DARK_ORANGE_END}"
                                 )
                             break
                     else:
+                        console.print(f"> {ERROR} Failed to fetch model details")
                         console.print(
-                            "> [red]ERROR[/red] Failed to fetch model details"
-                        )
-                        console.print(
-                            f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+                            f'''> Reason for failure {SAD_SMILEY}:
+                            " {RED_START}{json_response['message']}{RED_END} "'''
                         )
                         break
-                    status.update(f"Model is {current_status} 🧍")
+                    status.update(f"Model is {current_status} {PERSON_STANDING}")
                     await sleep(wait_interval)
-                    status.update(f"Model is {current_status} 🏋")
+                    status.update(f"Model is {current_status} {PERSON_DUMBELL}")
             console.print(
-                f"> [deep_sky_blue2]INFO[/deep_sky_blue2] "
+                f"> {INFO} "
                 f"{get_training_status_colour(json_response[DATA][TRAINING_STATUS])} "
                 f"Training status: {json_response[DATA][TRAINING_STATUS]}"
             )
@@ -589,10 +600,10 @@ async def train_model(
     wait_time: int = 1,
 ) -> Tuple[Dict[Text, Any], Dict[Text, Any]]:
     console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Queuing training job for: \n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Project ID: {project_id}\n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Language: {language}\n"
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Model Name: {model_name}"
+        f"> {INFO} Queuing training job for: \n"
+        f"> {INFO} Project ID: {project_id}\n"
+        f"> {INFO} Language: {language}\n"
+        f"> {INFO} Model Name: {model_name}"
     )
     payload = {PROJECT_ID: project_id, LANGUAGE: language, MODEL_NAME: model_name}
     HEADERS = copy(COMMON_HEADERS)
@@ -605,24 +616,20 @@ async def train_model(
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print(
-                "> [deep_sky_blue2]INFO[/deep_sky_blue2] Training job queued successfully"
-            )
+            console.print("> {INFO} Training job queued successfully")
             model_id = json_response[DATA]["model_id"]
             last_model_status = await wait_till_training_completes(
                 model_id, wait, wait_time
             )
         else:
-            console.print("> [red]ERROR[/red] Failed to queue training job")
-            console.print(f"> [red]ERROR[/red] {json_response['message']}")
+            console.print(f"> {ERROR} Failed to queue training job")
+            console.print(f"> {ERROR} {json_response['message']}")
             last_model_status = None
     return json_response, last_model_status
 
 
 async def delete_models(model_id: Text) -> Dict[Text, Any]:
-    console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting model with id: {model_id}"
-    )
+    console.print(f"> {INFO} {BIN} Deleting model with id: {model_id}")
     payload = {MODEL_ID: model_id}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -633,23 +640,21 @@ async def delete_models(model_id: Text) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
+            console.print(f"> {INFO} {GREEN_TICK} Successfully deleted model")
             console.print(
-                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted model"
-            )
-            console.print(
-                f"⏩ To upload the dataset: [dark_orange3]{UPLOAD_DATASET_COMMAND}[/dark_orange3]"
+                f"{FAST_FORWARD} To upload the dataset: {DARK_ORANGE_START}{UPLOAD_DATASET_COMMAND}{DARK_ORANGE_END}"
             )
         else:
-            console.print("> [red]ERROR[/red] ❌ Failed to delete models")
+            console.print(f"> {ERROR} {CROSS} Failed to delete models")
             console.print(
-                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
             )
     return json_response
 
 
 async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
     console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⤴️ Deploying: Model ID: {model_id}; Replicas: {n_replicas};"
+        f"> {INFO} {ARROW_UP}️ Deploying: Model ID: {model_id}; Replicas: {n_replicas};"
     )
     payload = {MODEL_ID: model_id, N_REPLICAS: n_replicas}
     HEADERS = copy(COMMON_HEADERS)
@@ -662,16 +667,14 @@ async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
+            console.print(f"> {INFO} {GREEN_TICK} Model deployed successfully")
             console.print(
-                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Model deployed successfully"
-            )
-            console.print(
-                f"⏩ To parse the model: [dark_orange3]{PARSE_MODEL_COMMAND}[/dark_orange3]"
+                f"{FAST_FORWARD} To parse the model: {DARK_ORANGE_START}{PARSE_MODEL_COMMAND}{DARK_ORANGE_END}"
             )
         else:
-            console.print("> [red]ERROR[/red] ❌ Failed to deploy model")
+            console.print(f"> {ERROR} {CROSS} Failed to deploy model")
             console.print(
-                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
             )
     return json_response
 
@@ -700,7 +703,7 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
             row["name"],
             str(row["confidence"]),
         )
-    console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] Intent Ranking")
+    console.print(f"> {INFO} Intent Ranking")
     console.print(intent_ranking_table)
     formatted_entities = []
     for e in nlu_response["data"]["entities"]:
@@ -713,7 +716,7 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
 
 async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
     console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📝 Parsing text: {input_text}, using Model ID: {model_id}"
+        f"> {INFO} {PEN_AND_PAPER} Parsing text: {input_text}, using Model ID: {model_id}"
     )
     payload = {MODEL_ID: model_id, DATA: {TEXT: input_text}}
     HEADERS = copy(COMMON_HEADERS)
@@ -729,13 +732,11 @@ async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
         response_time = (end - start).microseconds
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print(
-                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully parsed text"
-            )
+            console.print(f"> {INFO} {GREEN_TICK} Successfully parsed text")
             print_nlu_response(json_response, response_time)
         else:
-            console.print("> [red]ERROR[/red] ❌ Failed to parse model")
+            console.print(f"> {ERROR} {CROSS} Failed to parse model")
             console.print(
-                f'''> Reason for failure 😔: " [red]{json_response['message']}[/red] "'''
+                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
             )
     return json_response
