@@ -1,14 +1,26 @@
 import asyncio
 import json
+import os
+import typing
+from contextvars import Context
+from inspect import Parameter
 from pathlib import Path
 from typing import List, Text
 
 import click
 import randomname
+from rasa.shared.importers.utils import training_data_from_paths
 from rich.console import Console
 
 from neuralspace.apis import get_async_http_session
-from neuralspace.constants import NAME_GENERATOR_CONFIG
+from neuralspace.constants import (
+    NAME_GENERATOR_CONFIG,
+    NER_TYPES,
+    ORANGE3_END,
+    ORANGE3_START,
+    RED_END,
+    RED_START,
+)
 from neuralspace.nlu.apis import (
     create_project,
     delete_examples,
@@ -25,11 +37,37 @@ from neuralspace.nlu.apis import (
     wait_till_training_completes,
 )
 from neuralspace.nlu.constants import SUPPORTED_LANGUAGES, TRAINING_PROGRESS
-from neuralspace.utils import print_logo, setup_logger
+from neuralspace.nlu.rasa_converter.rasaconverter import RasaConverter
+from neuralspace.utils import get_entity_list, print_logo, setup_logger
 
 console = Console()
 
 
+class MappingClass(click.ParamType):
+    name: Text = "mapping_class"
+
+    def convert(
+        self,
+        value: typing.Any,
+        param: typing.Optional["Parameter"],
+        ctx: typing.Optional["Context"],
+    ) -> typing.Any:
+        list_of_entity_mapping = value.split(",")
+        total_entity_mapping = []
+        for entities in list_of_entity_mapping:
+            total_entity_mapping.append(entities.split(":"))
+        for entities in total_entity_mapping:
+            try:
+                assert len(entities) == 2
+            except AssertionError:
+                console.print(
+                    f"{RED_START}Entities mapping is given in the wrong format, Right format is{RED_END} "
+                    f"{ORANGE3_START}'your_entity_name:ns_entity_name,your_entity_name...'{ORANGE3_END}"
+                )
+                return False
+        return total_entity_mapping
+
+
 @click.group(name="nlu")
 def nlu():
     pass
@@ -46,6 +84,81 @@ def nlu_get_languages(log_level: Text):
     loop.run_until_complete(get_async_http_session().close())
 
 
+@nlu.command(name="convert-dataset")
+@click.option(
+    "-f",
+    "--from-platform",
+    type=click.Choice(["dialogflow", "rasa"], case_sensitive=False),
+    required=True,
+    help="From where to convert data from [dialogflow, rasa]",
+)
+@click.option(
+    "-at",
+    "--auto-tag-entities",
+    type=click.BOOL,
+    default=False,
+    help="You can use auto-tag entities to tag the entities with our pre-trained entities",
+)
+@click.option(
+    "-L",
+    "--language",
+    type=click.STRING,
+    required=True,
+    help="List of languages. -L en -L de; You can add multiple languages",
+)
+@click.option(
+    "-em",
+    "--entity-mapping",
+    type=MappingClass(),
+    required=False,
+    help="You can give entities mapping like 'your_entity_name:ns_entity_name,...",
+)
+@click.option(
+    "-t",
+    "--data-type",
+    type=click.Choice(["train", "test"], case_sensitive=True),
+    help="you can decide whether you want it as test or train data",
+)
+@click.option(
+    "-d",
+    "--dataset-path",
+    required=True,
+    help="Name of the folder in which the dataset files are in",
+)
+def converter(
+    from_platform: Text,
+    auto_tag_entities: bool,
+    language: Text,
+    entity_mapping: List,
+    dataset_path: Text,
+    dataset_name: Text,
+):
+    if entity_mapping is not False:
+        if from_platform == "rasa":
+            convert = RasaConverter(language)
+            rasa_data = training_data_from_paths([dataset_path], language=language)
+            lookup_data = convert.lookup_converter(rasa_data.lookup_tables)
+            regex_data = convert.regex_converter(rasa_data.regex_features)
+            synonym_data = convert.synonym_converter(rasa_data.entity_synonyms)
+            training_data = convert.training_data_converter(rasa_data)
+            directory_to_save_files = os.path.join(
+                os.getcwd(), f"neuralspace_{dataset_name}"
+            )
+            os.mkdir(directory_to_save_files)
+            with open(os.path.join(directory_to_save_files, "lookup.json"), "w") as f:
+                json.dump(lookup_data, f)
+            with open(os.path.join(directory_to_save_files, "regex.json"), "w") as f:
+                json.dump(regex_data, f)
+            with open(os.path.join(directory_to_save_files, "synonym.json"), "w") as f:
+                json.dump(synonym_data, f)
+            with open(os.path.join(directory_to_save_files, "nlu.json"), "w") as f:
+                json.dump(training_data, f)
+        elif from_platform == "dialogflow":
+            pass
+    else:
+        pass
+
+
 @nlu.command(name="create-project")
 @click.option(
     "-p",
@@ -294,7 +407,6 @@ def nlu_list_examples(
     verbose: bool,
     log_level: Text,
 ):
-
     setup_logger(log_level=log_level)
     prepared_flag = False
     if prepared == "true":
@@ -375,7 +487,6 @@ def nlu_delete_example(example_id: List[Text], log_level: Text):
 def nlu_train_model(
     project_id: Text, language: Text, model_name: Text, wait: bool, wait_interval: int
 ):
-
     print_logo()
     if model_name is None:
         model_name = randomname.get_name(**NAME_GENERATOR_CONFIG)
@@ -479,7 +590,6 @@ def nlu_list_models(
     verbose: bool,
     log_level: Text,
 ):
-
     setup_logger(log_level=log_level)
     if training_status:
         training_status = list(training_status)
@@ -530,7 +640,6 @@ def nlu_delete_model(model_id: Text, log_level: Text):
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
 )
 def nlu_deploy(model_id: Text, n_replicas: int, log_level: Text):
-
     setup_logger(log_level=log_level)
     loop = asyncio.new_event_loop()
     loop.run_until_complete(deploy(model_id, n_replicas))
@@ -560,3 +669,30 @@ def nlu_parse(model_id: Text, input_text: Text, log_level: Text):
     loop = asyncio.new_event_loop()
     loop.run_until_complete(parse(model_id, input_text))
     loop.run_until_complete(get_async_http_session().close())
+
+
+@nlu.command(name="get-pretrained-entities")
+@click.option("-L", "--language", type=click.STRING, required=True)
+@click.option("-s", "--search", type=click.STRING, default="")
+@click.option("-p", "--page-number", type=click.INT, default=1)
+@click.option("-P", "--page-size", type=click.INT, default=5)
+@click.option(
+    "-T", "--entity-type", type=click.Choice(NER_TYPES), default="pre-trained"
+)
+@click.option(
+    "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
+)
+def get_pretrained_entities(
+    language: Text,
+    search: Text,
+    page_number: int,
+    page_size: int,
+    entity_type: Text,
+    log_level: Text,
+):
+    setup_logger(log_level=log_level)
+    loop = asyncio.new_event_loop()
+    loop.run_until_complete(
+        get_entity_list(language, search, page_number, page_size, entity_type)
+    )
+    loop.run_until_complete(get_async_http_session().close())
